@@ -488,6 +488,7 @@ skip_impl = (
     'virDomainGetPerfEvents',
     'virDomainSetPerfEvents',
     'virDomainGetGuestVcpus',
+    'virConnectBaselineHypervisorCPU',
 )
 
 lxc_skip_impl = (
@@ -1828,6 +1829,8 @@ def qemuBuildWrappers(module):
     fd.write("# Automatically written part of python bindings for libvirt\n")
     fd.write("#\n")
 
+    fd.write("import sys\n")
+
     fd.write("try:\n")
     fd.write("    import libvirtmod_qemu\n")
     fd.write("except ImportError:\n")
@@ -1894,7 +1897,7 @@ def qemuBuildWrappers(module):
         if ret[0] != "void":
             fd.write("    if ret is None: raise libvirt.libvirtError('" + name + "() failed')\n")
             if ret[0] == "virDomainPtr":
-                fd.write("    __tmp = virDomain(" + conn + ",_obj=ret)\n")
+                fd.write("    __tmp = libvirt.virDomain(" + conn + ", _obj=ret)\n")
                 fd.write("    return __tmp\n")
             else:
                 fd.write("    return ret\n")
@@ -1951,6 +1954,8 @@ def lxcBuildWrappers(module):
     if extra is not None:
         extra.close()
 
+    fd.write("import sys\n")
+
     fd.write("try:\n")
     fd.write("    import libvirtmod_lxc\n")
     fd.write("except ImportError:\n")
@@ -2007,7 +2012,7 @@ def lxcBuildWrappers(module):
         if ret[0] != "void":
             fd.write("    if ret is None: raise libvirt.libvirtError('" + name + "() failed')\n")
             if ret[0] == "virDomainPtr":
-                fd.write("    __tmp = virDomain(" + conn + ",_obj=ret)\n")
+                fd.write("    __tmp = libvirt.virDomain(" + conn + ", _obj=ret)\n")
                 fd.write("    return __tmp\n")
             else:
                 fd.write("    return ret\n")
